@@ -4,9 +4,9 @@ from rest_framework import serializers
 
 
 class Enums:
-    LIST_STATUS = ['ACTIVO', 'INACTIVO']
-    ACTIVO = 'ACTIVO'
-    INACTIVO = 'INACTIVO'
+    ACTIVO = 'Activo'
+    INACTIVO = 'Inactivo'
+    LIST_STATUS = [ACTIVO, INACTIVO]
     IMAGES = 'image/png'
     LIST_FILE_CONTENT_TYPE = [IMAGES]
     CREATE = 'Crear'
@@ -20,6 +20,9 @@ class Enums:
     COMMUNITY = 'Comunidad'
     STANDARD = 'Estándar'
     LIST_TYPE_INVITE_ROLE = [COMMUNITY, STANDARD]
+    JOB_OFFER = 'Oferta de trabajo'
+    DOCUMENT = 'Documento'
+    LIST_TYPE_CATEGORIES = [COMMUNITY, JOB_OFFER, DOCUMENT]
 
 
 class Constants:
